#!/bin/ksh
# evidence.sh 1.6 of 11/05/01
# @(#)evidence.sh	1.6
################################################################################
#                                                                              #
#                       INFORMIX SOFTWARE, INC.                                #
#                       PROPRIETARY DATA                                       #
#                                                                              #
#       THIS DOCUMENT CONTAINS TRADE SECRET DATA WHICH IS THE PROPERTY OF      #
#       INFORMIX SOFTWARE, INC.  THIS DOCUMENT IS SUBMITTED TO RECIPIENT IN    #
#       CONFIDENCE.  INFORMATION CONTAINED HEREIN MAY NOT BE USED, COPIED OR   #
#       DISCLOSED IN WHOLE OR IN PART EXCEPT AS PERMITTED BY WRITTEN AGREEMENT #
#       SIGNED BY AN OFFICER OF INFORMIX SOFTWARE, INC.                        #
#                                                                              #
#       THIS MATERIAL IS ALSO COPYRIGHTED AS AN UNPUBLISHED WORK UNDER         #
#       SECTIONS 104 AND 408 OF TITLE 17 OF THE UNITED STATES CODE.            #
#       UNAUTHORIZED USE, COPYING OR OTHER REPRODUCTION IS PROHIBITED BY LAW.  #
#                                                                              #
#  Created:     April 25, 1997                                                 #
#  Description: Default System Alarm Program Script                            #
#                                                                              #
#                                                                              #
#  When the server encounters an Assertion Failure, it calls this script with  #
#  the following 12 arguments:                                                 #
#                                                                              #
#  $1 Assertion event class (ALRM_AFWARN==1, ALRM_AFFAIL==2, ALRM_AFCRASH==3)  #
#  $2 ID of assertion instance (Currently unused)                              #
#  $3 Assertion failure file name                                              #
#  $4 Session ID                                                               #
#  $5 rstcb address                                                            #
#  $6 Thread ID                                                                #
#  $7 tcb address                                                              #
#  $8 Data 1 (bitmask)                                                         #
#  $9 Data 2 (Currently unused)                                                #
#  $10 Data 3 (Currently unused)                                               #
#  $11 Data 4 (Currently unused)                                               #
#  $12 Data 5 (Currently unused)                                               #
#                                                                              #
################################################################################
#                                                                              #
#                              GLOBALS                                         #
#  OnLine Administrators are encouraged to configure the behavior of this      #
#  script by making use of the following globals:                              #

# OUTPUT                                                                       #
#      Setting OUTPUT to "off" will prevent any diagnostics and skip all       #
#      output.  This feature may be useful during testing.  The default value  #
#      is "on".                                                                #

OUTPUT=on

# BLOCK_SYSTEM                                                                 #
#      Set this variable to "on" if you would like the system frozen while     #
#      evidence is gathered.  The script will automatically release the        #
#      system when finished.  The default value is "off"                       #

BLOCK_SYSTEM=off 

# WRITE_TO_CONSOLE                                                             #
#      Set this variable to "off" to prevent a summary description of the      #
#      failure from being written to the console (as defined by CONSOLE in     #
#      your OnLine configuration file).  The default value is "on".            #

WRITE_TO_CONSOLE=off

# Email notification                                                           #
#      The script can be configured to email a notification of the failure     #
#      to a local DBA as well as to a special "RAS" alias within Informix      #
#      Software. ("RAS" stands for "Reliability, Availability and              #
#      Supportability"--the project that spawned SYSALARMPROG.)               #
# SEND_DBA_MAIL                                                                #
#      Set this global to "on" if you would like the script to send email to   #
#      a local DBA.  The default is "off".                                     #
# DBA                                                                          #
#      Set DBA to the email address of the local DBA.  By default, DBA is set  #
#      to "informix".                                                          #
# SEND_RAS_MAIL                                                                #
#      Set this global to "on" if you would like the script to send email to   #
#      the "RAS" alias at Informix Software.  The default is "on".             #
# RAS                                                                          #
#      Set RAS to the email address of the "RAS" alias at Informix Software.   #
#      RAS is set to "rasnotice@informix.com" by default.                      #
 
MAILFILE=${INFORMIXDIR:-/usr/informix}/alarm.nomail
if [ -r ${MAILFILE} ]
then
	SEND_DBA_MAIL=off
else
	SEND_DBA_MAIL=on
fi
DBA=dba@s1.com
SEND_RAS_MAIL=off
RAS=rasnotice@informix.com
 
# COMPRESS                                                                     #
#      Depending on the type of assertion failure and the current value of     #
#      the relavent AF* configuration parameter, this script may produce a     #
#      shared memory dump.  By default, the shared memory data is piped        #
#      directly into the command stored in the COMPRESS global, whose output   #
#      is then redirected into a file.  The idea is to set COMPRESS equal to   #
#      a compression command, thus avoiding the creation of a full-size        #
#      shared memory dump file which could overwhelm the file system           #
#      containing DUMPDIR.   By default COMPRESS is set to the "compress"      #
#      command, but any compression program will do, as long as it accepts     #
#      input from standard in and sends it to standard out.  Note that the     #
#      command must be fully enclosed in double quotes (") if it involves any  #
#      arguments.                                                              #
#      If you would prefer that the shared memory data *not* be compressed,    #
#      set the COMPRESS global to "None".                                      #

COMPRESS="compress"     # This command must be quoted if it involves arguments.
                        # Set to "None" for no compression
# COMPRESS_SUFFIX                                                              #
#      When producing a compressed shared memory dump it's best to give the    #
#      file an appropriate suffix.  Since COMPRESS is set to the "compress"    #
#      command by default, the default suffix is "Z".  Note that a "." will    #
#      automatically separate the suffix from the rest of the file name.       #

COMPRESS_SUFFIX="Z"

# DIAG_AFWARN                                                                  #
#      By default, diagnostics are not performed for assertion warnings, but   #
#      only for assertion *failures*.  To perform diagnostics for warnings as  #
#      well, set this variable to "on".                                        #
 
DIAG_AFWARN=off

# DEBUG                                                                        #
#      If this script is behaving strangely, setting this global to "on" can   #
#      help with troubleshooting, providing a window into variable settings,   #
#      for example.  The default value is "off".                               #
 
DEBUG=off
 
################################################################################

if [ "$OUTPUT" = "off" ]
then  # We have nothing to live for...
    exit 0
fi

################################################################################
#                              Script Arguments                                #
################################################################################
AF_CLASS=$1	# Assertion Failure Class 
AF_ID=$2	# Unused
AF_FILE=$3	# Assertion Failure file name
SES_ID=$4	# Session ID
RSTCB=$5	# RSAM Task Control Block address
THREAD_ID=$6	# Thread ID 
TCB=$7		# Thread Control Block address
BITMASK=$8	# Value of AFWARN, AFFAIL, or AFCRASH config param

################################################################################
#                              Function Definitions                            #
################################################################################

#+++++++++++++++++++++++++++++++ General functions +++++++++++++++++++++++++++++

ev_append()
{
$* >> $AF_FILE
}

ev_append_console()
{
if [ "$WRITE_TO_CONSOLE" = "on" -a -w $CONSOLE ]
then
    $* >> $CONSOLE
fi
}

ev_echo()
{
ev_append echo $*
}

ev_echo_console()
{
if [ "$WRITE_TO_CONSOLE" = "on" -a -w $CONSOLE ]
then
    echo $* >> $CONSOLE
fi
}

ev_echo_n()
{
echo $*\\t\\c >> $AF_FILE
}

ev_echo_n_console()
{
if [ "$WRITE_TO_CONSOLE" = "on" -a -w $CONSOLE ]
then
    echo $*\\t\\c >> $CONSOLE
fi
}

ev_overwrite()
{
$* > $AF_FILE
}

first_char()
{
if [ `echo $1 | cut -c1` = "$2" ]
then
    return 1
else
    return 0
fi
}

bitval()
{
bitset=$1
bitmask=$2
 
if [ $bitset -lt 0 ]
then
    if [ $bitmask -lt 0 ]
    then
        return 1
    fi
    bitset=`expr $bitset + 2147483648`
fi
if [ $bitset -gt 1073741824 ]
then
    if [ $bitmask -eq 1073741824 ]
    then
        return 1
    fi
fi
twice_bitmask=`expr 2 \* $bitmask`
if [ `expr $bitset % $twice_bitmask` -ge $bitmask ]
then
    return 1
fi
return 0
}

get_config_value()
{
param=$1
if [ "x$param" = "x" ]
then
    RETURN_VAL=NULL
    return
fi

ln=`onstat -c | grep $param | grep -v "^#" | awk '{print $1 " " $2}' | tail -1`
par=`echo $ln | awk '{print $1}'`
val=`echo $ln | awk '{print $2}'`
if [ "$par" != "$param" ]
then
    RETURN_VAL=NULL
    return
fi

first_char $val "#"
if [ $? -eq 1 ]
then
    RETURN_VAL=NULL
else
    RETURN_VAL=$val
fi
}

ev_pretty_header()
{
ev_echo "===========------------- - - - - - -"
}

ev_pretty()
{
ev_pretty_header
ev_echo $*:
ev_append $*
ev_echo " "
ev_echo " "
}

#+++++++++++++++++++++  Functions to run oncheck commands  +++++++++++++++++++++

#+++++++++++++++ Functions to run various common UNIX commands +++++++++++++++++

#+++++++++++++++++++++++++++++ Other functions +++++++++++++++++++++++++++++++++

 
################################################################################
#                         Tech Support Globals                                 #
################################################################################
# The following variables should be modified by Informix Tech Support only:    #

DO_ONSTAT_G_ALL=off	# "on" or "off"  (Default is "off")
DO_ONSTAT_A=off		# "on" or "off"  (Default is "off")
PRINT_POOL=off		# "on" or "off"  (Default is "off")
SHORT_BLOCK_TIME=600	# Ten minutes ought to be enough for the onstats
LONG_BLOCK_TIME=3600	# This is for the shared memory dump
get_config_value CONSOLE
if [ "$RETURN_VAL" = "NULL" ]
then
    CONSOLE=/dev/null
else
    CONSOLE=$RETURN_VAL
fi
get_config_value DUMPDIR
if [ "$RETURN_VAL" = "NULL" ]
then
    DUMPDIR=/tmp
else
    DUMPDIR=$RETURN_VAL
fi

IBIN=$INFORMIXDIR/bin
ONSTAT=$IBIN/onstat
ONCHECK=$IBIN/oncheck
ONMODE=$IBIN/onmode

PATH=/usr/bin:${PATH} #Attempting to ensure that we get the right echo command

POOL=0  # This may be of use eventually, when we're passed an assertion 
        # instance ID.
 

################################################################################
#                           Other Initializations                              #
################################################################################
# These variables aren't meant to be configured at all.  Please don't touch.   #

ALRM_AFWARN=1
ALRM_AFFAIL=2
ALRM_AFCRASH=3
RETURN_VAL=NULL
display_message=0
dump_core_file=0
dump_gcore_file=0
dump_shared_memory=0
hang_server=0
required_thread_hang=0
checkhang=0
checkcrash=0
checkrelease=0
crash_server=0


################################################################################
#                           Local Initializations                              #
################################################################################
# These variables are meant to be configured for the local installation.       #
OPS_PIN=7992239
OPS_PAGER=skytel.com


################################################################################
#                                                                              #
#                           MAIN BODY OF SCRIPT                                #
#                                                                              #
################################################################################

ev_echo " "
ev_echo "---------------------------------"
ev_echo "Begin System Alarm Program Output"
ev_echo "---------------------------------"
ev_echo " "

# First let's make sure shared memory is up.  If not, there's no point
# in going further.  Still send email and/or page (or IT/O message).
 
BAD=`$ONSTAT - | grep -c "shared memory not initialized"` 
if [ $BAD -gt 0 ]
then
    if [ "$SEND_DBA_MAIL" = "on" ]
    then
        HOSTNAME=`uname -n`
        if [ "$AF_CLASS" = "$ALRM_AFWARN" ]
	then
            # Send an email to the DBA team.
            echo "Assertion Warning for Informix Database on ${HOSTNAME} on `date`." > /tmp/page.$$
            mailx -s "Assertion Warning for Informix Database on ${HOSTNAME} on `date`" ${DBA} < /tmp/page.$$
            rm /tmp/page.$$
	else
            # Send an HP IT/O message if IT/O is installed, otherwise page operations.
            echo "Assertion Failure for Informix Database on ${HOSTNAME} on `date`." > /tmp/page.$$
            echo "Contact production DBA immediately." >> /tmp/page.$$
            if [ -s /opt/OV/bin/OpC/opcmsg ]
            then
                /opt/OV/bin/OpC/opcmsg severity=critical application=DBA object=Informix msg_text="`cat /tmp/page.$$`" msg_grp=Database
            else
                mail ${OPS_PIN}@${OPS_PAGER} < /tmp/page.$$
            fi
            mailx -s "Assertion Failure for Informix Database on ${HOSTNAME} on `date`" ${DBA} < /tmp/page.$$
            rm /tmp/page.$$
        fi
    fi
    ev_echo "Shared memory is not initialized."
    ev_echo "SYSALARMPROG quitting."
    ev_echo " "
    ev_echo "-------------------------------"
    ev_echo "End System Alarm Program Output"
    ev_echo "-------------------------------"
    ev_echo " "
    exit 1
fi


if [ "$DEBUG" = "on" ]
then
    ev_echo " "
    ev_echo "+-+-+-+-+-+-+-+-+-+-+-+-+-+"
    ev_echo "SYSALARMPROG Debug Info ON"
    ev_echo "+-+-+-+-+-+-+-+-+-+-+-+-+-+"
    ev_echo " "
fi

if [ "$DEBUG" = "on" ]
then
    ev_echo "Arguments:"
    ev_echo "AF_CLASS=$AF_CLASS"
    ev_echo "AF_ID=$AF_ID"
    ev_echo "AF_FILE=$AF_FILE"
    ev_echo "SES_ID=$SES_ID"
    ev_echo "RSTCB=$RSTCB"
    ev_echo "THREAD_ID=$THREAD_ID"
    ev_echo "TCB=$TCB"
    ev_echo "BITMASK=$BITMASK"
fi

# The bitmask, passed as parameter number 8, is the value of the
# assertion failure configuration parameter (AFCRASH, AFFAIL, or AFWARN)
# associated with this event.  These bits help us understand how the
# engine will react to the event, and we can base some decisions on
# that (future) reaction.
#
# The bitmask is a combination of bit values with the following meanings:
#
# Bitmask value         Desired result
# -------------         --------------
# 0x1                   Display message to message file
# 0x2                   Dump a core file
# 0x4                   Dump a gcore file
# 0x8                   Dump shared memory
# 0x10                  Hang server
# 0x20                  Hang thread
# 0x40                  Hang thread if possible, otherwise hang server
# 0x80                  Hang thread if possible, otherwise crash server
# 0x100                 Hang thread if possible, otherwise allow it to
#                       continue
# 0x200                 Crash server
# 0x400			Generate stack within oninit process
# 0x800			Do NOT call evidence.sh
#
# In the case of bit value 0x8, this script is responsible for dumping
# shared memory.  In all other cases the server is responsible for taking
# the desired action.

if [ "$DEBUG" = "on" ]
then
    ev_echo "Bits on:"
fi

bitval $BITMASK 1
if [ $? -eq 1 ]
then
    display_message=1
    if [ "$DEBUG" = "on" ]
    then
	ev_echo "display_message (Server will display message to message file)"
    fi
fi

bitval $BITMASK 2
if [ $? -eq 1 ]
then
    dump_core_file=1
    if [ "$DEBUG" = "on" ]
    then
        ev_echo "dump_core_file (Server will produce a core file)"
    fi  
fi
bitval $BITMASK 4
if [ $? -eq 1 ]
then
    dump_gcore_file=1
    if [ "$DEBUG" = "on" ]
    then
        ev_echo "dump_gcore_file (Server will produce a gcore file)"
    fi
fi
bitval $BITMASK 8
if [ $? -eq 1 ]
then
    dump_shared_memory=1
    if [ "$DEBUG" = "on" ]
    then
        ev_echo "dump_shared_memory (SYSALARMPROG will dump shared memory)"
    fi
fi
bitval $BITMASK 16
if [ $? -eq 1 ]
then
    hang_server=1
    if [ "$DEBUG" = "on" ]
    then
        ev_echo "hang_server (Server will hang)"
    fi
fi
bitval $BITMASK 32
if [ $? -eq 1 ]
then
    required_thread_hang=1
    if [ "$DEBUG" = "on" ]
    then
        ev_echo "required_thread_hang (Thread will hang)"
    fi
fi
bitval $BITMASK 64
if [ $? -eq 1 ]
then
    checkhang=1
    if [ "$DEBUG" = "on" ]
    then
        ev_echo "checkhang (Either thread will hang or server will hang)"
    fi
fi
bitval $BITMASK 128
if [ $? -eq 1 ]
then
    checkcrash=1
    if [ "$DEBUG" = "on" ]
    then
        ev_echo "checkcrash (Either thread will hang or server will crash)"
    fi
fi
bitval $BITMASK 256
if [ $? -eq 1 ]
then
    checkrelease=1
    if [ "$DEBUG" = "on" ]
    then
        ev_echo "checkrelease (Either thread will hang or thread will)"
    fi
fi
bitval $BITMASK 512
if [ $? -eq 1 ]
then
    crash_server=1
    if [ "$DEBUG" = "on" ]
    then
        ev_echo "crash_server (Server will crash)"
    fi
fi

if [ "$DEBUG" = "on" ]
then
    ev_echo " "
    ev_echo "Global settings:"
    ev_echo "BLOCK_SYSTEM=$BLOCK_SYSTEM"
    ev_echo "DIAG_AFWARN=$DIAG_AFWARN"
    ev_echo "WRITE_TO_CONSOLE=$WRITE_TO_CONSOLE"
    ev_echo "DBA=$DBA"
    ev_echo "SEND_DBA_MAIL=$SEND_DBA_MAIL"
    ev_echo "RAS=$RAS"
    ev_echo "SEND_RAS_MAIL=$SEND_RAS_MAIL"
    ev_echo "COMPRESS=$COMPRESS"
    ev_echo "COMPRESS_SUFFIX=$COMPRESS_SUFFIX"
    ev_echo "DO_ONSTAT_G_ALL=$DO_ONSTAT_G_ALL"
    ev_echo "DO_ONSTAT_A=$DO_ONSTAT_A"
    ev_echo "PRINT_POOL=$PRINT_POOL"
    ev_echo "SHORT_BLOCK_TIME=$SHORT_BLOCK_TIME"
    ev_echo "LONG_BLOCK_TIME=$LONG_BLOCK_TIME"
    ev_echo "CONSOLE=$CONSOLE"
    ev_echo "DUMPDIR=$DUMPDIR"
    ev_echo "IBIN=$IBIN"
    ev_echo "ONSTAT=$ONSTAT"
    ev_echo "ONCHECK=$ONCHECK"
    ev_echo "ONMODE=$ONMODE"
    ev_echo " "
fi

# Send a summary of the problem to the AF file and (possibly) to the console.  #

ev_echo_n "Assertion Failure Type:"
ev_echo_n_console "Assertion Failure Type:"

case $1 in
    1 ) ev_echo "Warning" 
        ev_echo_console "Warning" ;;
    2 ) ev_echo "FAILURE"
        ev_echo_console "FAILURE" ;;
    3 ) ev_echo "CRASH"
        ev_echo_console "CRASH" ;;
esac

get_config_value DBSERVERNAME
DBSERVERNAME=$RETURN_VAL
HOSTNAME=`uname -n`

ev_echo "Host Name:\\t\\t$HOSTNAME"
ev_echo_console "Host Name:\\t\\t$HOSTNAME"

ev_echo "Database Server Name:\\t$DBSERVERNAME"
ev_echo_console "Database Server Name:\\t$DBSERVERNAME"

ev_echo_n "Time of failure:"
ev_echo_n_console "Time of failure:"
ev_append date
ev_append_console date

ev_echo "AF file:\\t\\t$AF_FILE"
ev_echo_console "AF file:\\t\\t$AF_FILE"

if [ "$dump_shared_memory" = "1" ]
then
    DONE=0
    CNT=0
    while [ "$DONE" = "0" ]
    do
        SUFFIX=`basename $AF_FILE`
        DUMPFILE=${DUMPDIR}/shmem.${SUFFIX}.${CNT}
        if [ "$COMPRESS" != "None" ]
        then
            DUMPFILE=${DUMPFILE}.${COMPRESS_SUFFIX}
        fi
	if [ ! -f $DUMPFILE ]
	then
	    DONE=1
	else
	    CNT=`expr $CNT + 1`
	fi
    done
else
    DUMPFILE="None"
fi
ev_echo "Shared memory file:\\t$DUMPFILE"
ev_echo_console "Shared memory file:\\t$DUMPFILE"

ev_echo_n "System Blocking:"
ev_echo_n_console "System Blocking:"
if [ "$BLOCK_SYSTEM" = "on" ]
then
    ev_echo "ON"
    ev_echo_console "ON"
    $ONMODE -i block $SHORT_BLOCK_TIME
else
    ev_echo "OFF"
    ev_echo_console "OFF"
fi

ev_echo " "
ev_echo " "
ev_echo_console " "
ev_echo_console " "

# End summary #


if [ "$AF_CLASS" = "$ALRM_AFWARN" -a "$DIAG_AFWARN" != "on" ]
then
    if [ "$BLOCK_SYSTEM" = "on" ]
    then
	$ONMODE -i unblock
    fi
    if [ "$SEND_DBA_MAIL" = "on" ]
    then
        echo "Assertion Warning for Informix Database on ${HOSTNAME} on `date`." > /tmp/page.$$
        mailx -s "Assertion Warning for Informix Database on ${HOSTNAME} on `date`" ${DBA} < /tmp/page.$$
        rm /tmp/page.$$
    fi
    ev_echo "-------------------------------"
    ev_echo "End System Alarm Program Output"
    ev_echo "-------------------------------"
    ev_echo " "
    exit 0
fi

get_config_value MSGPATH
MSGPATH=$RETURN_VAL

if [ "$MSGPATH" = "NULL" ]
then
    ev_pretty onstat -m
else
    ev_pretty_header
    ev_echo "tail -100 $MSGPATH:"
    ev_echo " "
    ev_append tail -100 $MSGPATH
    ev_echo " "
    ev_echo " "
fi

if [ $THREAD_ID -gt 1 ]
then
    ev_pretty_header
    ev_echo "$ONSTAT -g ath:"
    # The following command parses an onstat -g ath and adds a "*" to the
    # beginning of the line for the thread that failed.
    $ONSTAT -g ath |
    awk '{if ( $1 ~ /'"^$THREAD_ID$"'/ ) print "*"substr($0,2);
    else print $0}' >> $AF_FILE
    ev_echo " "
else
    ev_pretty $ONSTAT -g ath
fi


if [ "$THREAD_ID" = "0" ]
then
    ev_pretty $ONSTAT -g stk all      #System is already blocked
    GOT_ALL_STACKS=yes
else
    if [ "$BLOCK_SYSTEM" = "on" ]
    then
	ev_pretty $ONSTAT -g stk $THREAD_ID     #System is already blocked
    else
	ev_pretty $ONSTAT -g stk $THREAD_ID light
    fi
    GOT_ALL_STACKS=no
fi


if [ "$SES_ID" != "0" ]
then
    ev_pretty_header
    ev_echo "$ONSTAT -u:"
    # The following command parses an onstat -u and adds a "*" to the
    # line for the session that failed.
    $ONSTAT -u | awk '{if ( $3 ~ /'"^$SES_ID$"'/ && $2 !~ /active/ )
    print substr($0,1,16)"*"substr($0,18); else print $0}' >> $AF_FILE
    ev_echo " "
    ev_echo " "
    ev_pretty $ONSTAT -g ses $SES_ID
    ev_pretty $ONSTAT -g sql $SES_ID
fi

if [ "$DO_ONSTAT_A" = "on" ]
then
    ev_pretty $ONSTAT -a
else
   #ev_pretty $ONSTAT -m	# We already have message log info
    ev_pretty $ONSTAT -c
    if [ "$SES_ID" = "0" ]	# Otherwise we've already got an onstat -u
    then
	ev_pretty $ONSTAT -u
    fi
    ev_pretty $ONSTAT -s
    ev_pretty $ONSTAT -k
    ev_pretty $ONSTAT -b
    ev_pretty $ONSTAT -t
    ev_pretty $ONSTAT -d
    ev_pretty $ONSTAT -l
    ev_pretty $ONSTAT -p
    ev_pretty $ONSTAT -x
    ev_pretty $ONSTAT -f
    ev_pretty $ONSTAT -h
    ev_pretty $ONSTAT -C
    ev_pretty $ONSTAT -F
    ev_pretty $ONSTAT -R

    if [ "$DO_ONSTAT_G_ALL" = "on" ]
    then
	ev_pretty $ONSTAT -g all
    else
	ev_pretty $ONSTAT -g glo
	ev_pretty $ONSTAT -g qst
	ev_pretty $ONSTAT -g wst
       #ev_pretty $ONSTAT -g ath	# Already have this.
       #ev_pretty $ONSTAT -g wai	# These four
       #ev_pretty $ONSTAT -g act	# are redundant
       #ev_pretty $ONSTAT -g rea	# with 
       #ev_pretty $ONSTAT -g sle	# onstat -g ath
	ev_pretty $ONSTAT -g lmx
	ev_pretty $ONSTAT -g wmx
	ev_pretty $ONSTAT -g con
	if [ "$GOT_ALL_STACKS" = "no" ]
	then
	    ev_pretty $ONSTAT -g stk all
	fi
	ev_pretty $ONSTAT -g mem
	ev_pretty $ONSTAT -g seg
	ev_pretty $ONSTAT -g rbm
	ev_pretty $ONSTAT -g nbm
	ev_pretty $ONSTAT -g dic
	ev_pretty $ONSTAT -g dsc
	ev_pretty $ONSTAT -g prc
	ev_pretty $ONSTAT -g cac
	ev_pretty $ONSTAT -g sch
	ev_pretty $ONSTAT -g pos
        if [ "$PRINT_POOL" = "on" -a "$POOL" != "0" ]
	then
	    ev_pretty $ONSTAT -g afr $POOL
	    ev_pretty $ONSTAT -g ffr $POOL
	    ev_pretty $ONSTAT -g ufr $POOL
	fi
	ev_pretty $ONSTAT -g ioa
       #ev_pretty $ONSTAT -g iog	# These
       #ev_pretty $ONSTAT -g ioc	# commands
       #ev_pretty $ONSTAT -g iof	# are
       #ev_pretty $ONSTAT -g ioa	# all
       #ev_pretty $ONSTAT -g ioq	# redundant
       #ev_pretty $ONSTAT -g iov	# with
       #ev_pretty $ONSTAT -g iob	# onstat -g ioa
	ev_pretty $ONSTAT -g nta
       #ev_pretty $ONSTAT -g ntu	# These
       #ev_pretty $ONSTAT -g ntt	# are
       #ev_pretty $ONSTAT -g ntm	# redundant with
       #ev_pretty $ONSTAT -g ntd	# onstat -g nta
	ev_pretty $ONSTAT -g nsd
	ev_pretty $ONSTAT -g nsc
       #ev_pretty $ONSTAT -g ntb	# NT only
	ev_pretty $ONSTAT -g nss
	ev_pretty $ONSTAT -g sts
	ev_pretty $ONSTAT -g ses
	ev_pretty $ONSTAT -g sql
	ev_pretty $ONSTAT -g stq
	ev_pretty $ONSTAT -g opn
	ev_pretty $ONSTAT -g dri
	ev_pretty $ONSTAT -g ppf
	ev_pretty $ONSTAT -g tpf
	ev_pretty $ONSTAT -g tgp
	ev_pretty $ONSTAT -g pgp
	ev_pretty $ONSTAT -g mgm
	ev_pretty $ONSTAT -g smb s
	ev_pretty $ONSTAT -g smb c
	ev_pretty $ONSTAT -g lsc
	ev_pretty $ONSTAT -g lap
	ev_pretty $ONSTAT -g ddr
	ev_pretty $ONSTAT -g dis
	ev_pretty $ONSTAT -g arc
	ev_pretty $ONSTAT -g dll
	ev_pretty $ONSTAT -g sym
	ev_pretty $ONSTAT -g ras
    fi
fi

################################################################################
# These are obscure / verbose onstat commands that probably don't need to be   #
# turned on here.                                                              #
#                                                                              #
# ev_pretty $ONSTAT -D                                                         #
# ev_pretty $ONSTAT -B                                                         #
# ev_pretty $ONSTAT -X                                                         #
# ev_pretty $ONSTAT -P                                                         #
# ev_pretty $ONSTAT -K                                                         #
# ev_pretty $ONSTAT -g amx                                                     #
# ev_pretty $ONSTAT -g spi                                                     #
#                                                                              #
################################################################################

ev_pretty_header
ev_echo "Environment Variables:"
ev_echo " "
ev_append env
ev_echo " "
ev_echo " "

ev_pretty $IBIN/oninit -V
ev_pretty $ONSTAT -V
ev_pretty $ONCHECK -V
ev_pretty $ONMODE -V
ev_pretty uname -a

if [ "$SEND_DBA_MAIL" = "on" ]
then
    if [ "$AF_CLASS" = "$ALRM_AFWARN" ]
    then
        # Send an email to the DBA team.
        echo "Assertion Warning for Informix Database on ${HOSTNAME} on `date`." > /tmp/page.$$
        mailx -s "Assertion Warning for Informix Database on ${HOSTNAME} on `date`" ${DBA} < /tmp/page.$$
        rm /tmp/page.$$
    else
        # Send an HP IT/O message if IT/O is installed, otherwise page operations.
        echo "Assertion Failure for Informix Database on ${HOSTNAME} on `date`." > /tmp/page.$$
        echo "Contact production DBA immediately." >> /tmp/page.$$
	echo "File containing information on failure is $AF_FILE" >> /tmp/page.$$
        if [ -s /opt/OV/bin/OpC/opcmsg ]
        then
            /opt/OV/bin/OpC/opcmsg severity=critical application=DBA object=Informix msg_text="`cat /tmp/page.$$`" msg_grp=Database
        else
            mail ${OPS_PIN}@${OPS_PAGER} < /tmp/page.$$
        fi
        mailx -s "Assertion Failure for Informix Database on ${HOSTNAME} on `date`" ${DBA} < /tmp/page.$$
        rm /tmp/page.$$
    fi
fi
if [ "$SEND_RAS_MAIL" = "on" ]
then
    mailx -s "Assertion Failure on $HOSTNAME ($DBSERVERNAME)" $RAS < $AF_FILE
fi

# This block time extension is done so that if this script fails or exits
# above this point for any reason, the system won't be blocked for long (a
# max of SHORT_BLOCK_TIME).  However, we do want the system to be blocked
# during the entire shared memory dump (when blocking is on).

if [ "$BLOCK_SYSTEM" = "on" ]
then
    $ONMODE -i extend $LONG_BLOCK_TIME
fi

if [ "$dump_shared_memory" = "1" ]
then
    if [ "$COMPRESS" = "None" ]
    then
        $ONSTAT -g out > $DUMPFILE
    else
        $ONSTAT -g out | $COMPRESS > $DUMPFILE
    fi
fi

if [ "$BLOCK_SYSTEM" = "on" ]
then
    $ONMODE -i unblock
fi

ev_echo "-------------------------------"
ev_echo "End System Alarm Program Output"
ev_echo "-------------------------------"
ev_echo " "
exit 0

