#!/bin/ksh
# onchecks.sh 1.6 of 05/24/01
# @(#)onchecks.sh	1.6
##########################################################################
# onchecks.sh
##########################################################################
# Script for doing basic oncheck commands against the Informix instance.
# Script is run weekly from Maestro at appropriate time for each server
# as the informix ID.
# 
# If a parameter is passed, this is a multi-instance server and the value
# of the parameter is the name of the instance being used here.
##########################################################################

# Set up environment

# Capture Informix information from .profile of informix ID and parameter.
INFHOME=`grep informix /etc/passwd | head -1 | cut -d: -f6`
grep INFORMIXDIR ${INFHOME}/.profile > ${INFHOME}/.tmponc.$$
if [ $# -eq 0 ]
then
        grep INFORMIXSERVER ${INFHOME}/.profile >> ${INFHOME}/.tmponc.$$
        grep ONCONFIG ${INFHOME}/.profile >> ${INFHOME}/.tmponc.$$
else
        export INFORMIXSERVER=${1}_shm
        export ONCONFIG=onconfig.${1}
fi
. ${INFHOME}/.tmponc.$$
rm ${INFHOME}/.tmponc.$$
export PATH=$PATH:$INFORMIXDIR/bin

DBA_MAIL="dba@s1.com"
HOST=`hostname`
TMPFILE=${TMPDIR:-/tmp}/onchecks.$$
if [ $# -eq 0 ]
then
        LOG_DIR="${INFORMIXDIR}/logs"
else
        LOG_DIR="/db_activity/${1}/logs"
fi

cd ${LOG_DIR}
rm -f onchecks.out

exec > onchecks.log 2>&1
date
env
onstat -

# Perform checks on all databases in the instance.
oncheck -cc > onchecks.out
oncheck -cr >> onchecks.out
oncheck -ce >> onchecks.out

WARN=`grep -c "arning" onchecks.out`
ERR=`grep -c "rror" onchecks.out`
TOT=`expr $WARN + $ERR`
if [ $TOT -gt 0 ]
then
	echo "There are errors and/or warnings in onchecks run on `date`"
	echo "for host ${HOST}, instance ${INFORMIXSERVER}!"
	echo "Check output in ${LOG_DIR}."
	echo "Error or warning in onchecks shell run on `date`" > ${TMPFILE}
	echo "for host ${HOST}, instance ${INFORMIXSERVER}." >> ${TMPFILE}
	echo "Check output in ${LOG_DIR} on the server for more details." >> ${TMPFILE}
	mailx -s "Error or warning in onchecks shell for host ${HOST}" ${DBA_MAIL} < ${TMPFILE}
else
	echo "No errors in onchecks run on `date`."
	date
fi

rm -f ${TMPFILE}

exit 0

