#!/bin/ksh
# prunelog.sh 1.11 of 07/22/02
# @(#)prunelog.sh	1.11
##########################################################################
# prunelog.sh 
##########################################################################
# Script for moving online, alarm, onprobe, and console logs to the log
# directory.  It also renames the various monitoring script output files.
# It then deletes from that directory any files that are more than 90 days
# old.  It is run monthly from Maestro on the last day of the month.
#
# If a parameter is passed, this is a multi-instance server and the value
# of the parameter is the name of the instance being used here.
##########################################################################

# Set trace on if necessary for debugging.
# set -o xtrace

# Set initial shell and contact variables. Separate date items due to SCCS.
MM=`date '+%m'`
DD=`date '+%d'`
HH=`date '+%H'`
SUFFIX=$MM$DD$HH

# Make sure that this shell is being run by the Informix ID.
if [ "${LOGNAME}" != informix ]
then
	echo "User ${LOGNAME} tried to run prune log shell and is not informix ID."
	exit 2 
fi

# Capture Informix information from .profile of informix ID and parameter.
INFHOME=`grep informix /etc/passwd | head -1 | cut -d: -f6`
grep INFORMIXDIR ${INFHOME}/.profile > ${INFHOME}/.tmppru.$$
if [ $# -eq 0 ]
then
        grep INFORMIXSERVER ${INFHOME}/.profile >> ${INFHOME}/.tmppru.$$
        grep ONCONFIG ${INFHOME}/.profile >> ${INFHOME}/.tmppru.$$
else
        export INFORMIXSERVER=${1}_shm
        export ONCONFIG=onconfig.${1}
fi
. ${INFHOME}/.tmppru.$$
rm ${INFHOME}/.tmppru.$$
export PATH=$PATH:$INFORMIXDIR/bin

# Set log storage directory and create it if not there.
if [ $# -eq 0 ]
then
        LOG_DIR="${INFORMIXDIR}/logs"
        INF_DIR="${INFORMIXDIR}"
else
        LOG_DIR="/db_activity/${1}/logs"
        INF_DIR="/db_activity/${1}"
fi
if [ ! -d ${LOG_DIR} ]
then
	mkdir ${LOG_DIR}
fi

# Move logs to log storage directory.
cd ${INF_DIR}
if [ -s alarm.log ]
then
	mv alarm.log ${LOG_DIR}/alarm.log.${SUFFIX}
fi
if [ -s console.log ]
then
	mv console.log ${LOG_DIR}/console.log.${SUFFIX}
fi
if [ -s online.log ]
then
	# Keep last 50 lines of online log for use by checkdb.sh
	tail -50 online.log > temp.log
	mv online.log ${LOG_DIR}/online.log.${SUFFIX}
	mv temp.log online.log
fi
if [ -s onprobe.log ]
then
	mv onprobe.log ${LOG_DIR}/onprobe.log.${SUFFIX}
fi

cd ${LOG_DIR}
if [ -s alarm.out ]
then
	mv alarm.out alarm.out.${SUFFIX}
fi
if [ -s blobpurge.log ]
then
	mv blobpurge.log blobpurge.log.${SUFFIX}
fi
if [ -s checkdb.out ]
then
	mv checkdb.out checkdb.out.${SUFFIX}
fi
if [ -s checkspc.out ]
then
	mv checkspc.out checkspc.out.${SUFFIX}
fi
if [ -s inf-backupdev.log ]
then
	mv inf-backupdev.log inf-backupdev.log.${SUFFIX}
fi
if [ -s updstat.log ]
then
	mv updstat.log updstat.log.${SUFFIX}
fi

# Delete all files that are older than 90 days
if [ -d ${LOG_DIR} ]
then
	cd ${LOG_DIR}
	find *.log.* -mtime +90 -exec rm -f {} \;
	find *.out.* -mtime +90 -exec rm -f {} \;
fi

exit 0

